LifeCycleManager class

A widget that manages app lifecycle events and provides callbacks for different lifecycle states.

Inheritance

Constructors

LifeCycleManager({Key? key, required Widget child, VoidCallback? onResumed, VoidCallback? onPaused, VoidCallback? onInactive, VoidCallback? onDetached, VoidCallback? onHidden, bool enableLogging = false})
const

Properties

child Widget
The child widget to wrap
final
enableLogging bool
Whether to enable debug logging of lifecycle events
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDetached VoidCallback?
Called when the app is detached
final
onHidden VoidCallback?
Called when the app is hidden
final
onInactive VoidCallback?
Called when the app becomes inactive
final
onPaused VoidCallback?
Called when the app is paused (moved to background)
final
onResumed VoidCallback?
Called when the app is resumed from background
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<LifeCycleManager>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited